@@ -40,11 +40,13 @@ venn.diagram <- function(
 	sigdigs = 3,
 	direct.area = FALSE,
 	area.vector = 0,
+	hyper.test = FALSE,
+	total.population = NULL,
 	...
 	) {
 	
 	#Create a string to capture the date and the time of day
-	time.string = paste(strsplit(as.character(Sys.time())," ")[[1]],collapse="-")
+	time.string = gsub(":", "-", gsub(" ", "_", as.character(Sys.time())))
 	
 	#Initialize the logger to output to file
 	if(!is.null(filename)){
@@ -399,7 +401,19 @@ stop('Incorrect number of elements.', call. = FALSE);
 stop('Invalid size of input object');
 			}
 		}
-		
+	
+	# if there are two sets in the VennDiagram and the hypergeometric test is requested then perform the test and add the pvalue to the subtitle
+	#p value always shown with 2 sig digs. Add another parameter for this later if you want to control the sig digs
+	
+	if (length(x) == 2 & !is.null(total.population) & hyper.test){
+		val.p = calculate.overlap.and.pvalue(x[[1]],x[[2]],total.population)
+		if(is.null(sub)){
+			sub = paste0("p = ",signif(val.p[3],digits=2))
+		}else{
+			sub = paste0(sub,", p = ",signif(val.p[3],digits=2))
+		}
+	}
+	
 	# if requested, add a sub-title
 	if (!is.null(sub)) {
 		grob.list <- add.title(
